@@ -14,9 +14,12 @@ class App:
     ExtensionContainer = 'App::ExtensionContainer'
     FeaturePython = 'App::FeaturePython'
     FeatureTest = 'App::FeatureTest'
+    FeatureTestAbsAddress = 'App::FeatureTestAbsAddress'
+    FeatureTestAttribute = 'App::FeatureTestAttribute'
     FeatureTestColumn = 'App::FeatureTestColumn'
     FeatureTestException = 'App::FeatureTestException'
     FeatureTestPlacement = 'App::FeatureTestPlacement'
+    FeatureTestRow = 'App::FeatureTestRow'
     FunctionExpression = 'App::FunctionExpression'
     GeoFeature = 'App::GeoFeature'
     GeoFeatureGroupExtension = 'App::GeoFeatureGroupExtension'
@@ -479,6 +482,7 @@ class Mesh:
     MeshObject = 'Mesh::MeshObject'
     MeshSegment = 'Mesh::MeshSegment'
     PropertyCurvatureList = 'Mesh::PropertyCurvatureList'
+    PropertyMaterial = 'Mesh::PropertyMaterial'
     PropertyMeshKernel = 'Mesh::PropertyMeshKernel'
     PropertyNormalList = 'Mesh::PropertyNormalList'
     RemoveComponents = 'Mesh::RemoveComponents'
@@ -832,11 +836,7 @@ class Path:
     FeatureShape = 'Path::FeatureShape'
     FeatureShapePython = 'Path::FeatureShapePython'
     PropertyPath = 'Path::PropertyPath'
-    PropertyTool = 'Path::PropertyTool'
-    PropertyTooltable = 'Path::PropertyTooltable'
-    Tool = 'Path::Tool'
     Toolpath = 'Path::Toolpath'
-    Tooltable = 'Path::Tooltable'
     Voronoi = 'Path::Voronoi'
     VoronoiCell = 'Path::VoronoiCell'
     VoronoiEdge = 'Path::VoronoiEdge'
@@ -990,6 +990,7 @@ class StartGui:
 class Surface:
     Cut = 'Surface::Cut'
     Extend = 'Surface::Extend'
+    FeatureBlendCurve = 'Surface::FeatureBlendCurve'
     Filling = 'Surface::Filling'
     GeomFillSurface = 'Surface::GeomFillSurface'
     Sections = 'Surface::Sections'
@@ -997,6 +998,7 @@ class Surface:
 
 
 class SurfaceGui:
+    ViewProviderBlendCurve = 'SurfaceGui::ViewProviderBlendCurve'
     ViewProviderExtend = 'SurfaceGui::ViewProviderExtend'
     ViewProviderFilling = 'SurfaceGui::ViewProviderFilling'
     ViewProviderGeomFillSurface = 'SurfaceGui::ViewProviderGeomFillSurface'
@@ -1010,6 +1012,8 @@ class TechDraw:
     CosmeticExtension = 'TechDraw::CosmeticExtension'
     CosmeticExtensionPython = 'TechDraw::CosmeticExtensionPython'
     CosmeticVertex = 'TechDraw::CosmeticVertex'
+    DrawComplexSection = 'TechDraw::DrawComplexSection'
+    DrawComplexSectionPython = 'TechDraw::DrawComplexSectionPython'
     DrawGeomHatch = 'TechDraw::DrawGeomHatch'
     DrawHatch = 'TechDraw::DrawHatch'
     DrawLeaderLine = 'TechDraw::DrawLeaderLine'
@@ -1039,12 +1043,11 @@ class TechDraw:
     DrawViewDimension = 'TechDraw::DrawViewDimension'
     DrawViewDraft = 'TechDraw::DrawViewDraft'
     DrawViewImage = 'TechDraw::DrawViewImage'
-    DrawViewMulti = 'TechDraw::DrawViewMulti'
-    DrawViewMultiPython = 'TechDraw::DrawViewMultiPython'
     DrawViewPart = 'TechDraw::DrawViewPart'
     DrawViewPartPython = 'TechDraw::DrawViewPartPython'
     DrawViewPython = 'TechDraw::DrawViewPython'
     DrawViewSection = 'TechDraw::DrawViewSection'
+    DrawViewSectionPython = 'TechDraw::DrawViewSectionPython'
     DrawViewSpreadsheet = 'TechDraw::DrawViewSpreadsheet'
     DrawViewSymbol = 'TechDraw::DrawViewSymbol'
     DrawViewSymbolPython = 'TechDraw::DrawViewSymbolPython'
@@ -1068,17 +1071,20 @@ class TechDrawGui:
     ViewProviderDimension = 'TechDrawGui::ViewProviderDimension'
     ViewProviderDraft = 'TechDrawGui::ViewProviderDraft'
     ViewProviderDrawingView = 'TechDrawGui::ViewProviderDrawingView'
+    ViewProviderDrawingViewExtension = 'TechDrawGui::ViewProviderDrawingViewExtension'
     ViewProviderGeomHatch = 'TechDrawGui::ViewProviderGeomHatch'
     ViewProviderHatch = 'TechDrawGui::ViewProviderHatch'
     ViewProviderImage = 'TechDrawGui::ViewProviderImage'
     ViewProviderLeader = 'TechDrawGui::ViewProviderLeader'
     ViewProviderPage = 'TechDrawGui::ViewProviderPage'
+    ViewProviderPageExtension = 'TechDrawGui::ViewProviderPageExtension'
     ViewProviderProjGroup = 'TechDrawGui::ViewProviderProjGroup'
     ViewProviderProjGroupItem = 'TechDrawGui::ViewProviderProjGroupItem'
     ViewProviderRichAnno = 'TechDrawGui::ViewProviderRichAnno'
     ViewProviderSpreadsheet = 'TechDrawGui::ViewProviderSpreadsheet'
     ViewProviderSymbol = 'TechDrawGui::ViewProviderSymbol'
     ViewProviderTemplate = 'TechDrawGui::ViewProviderTemplate'
+    ViewProviderTemplateExtension = 'TechDrawGui::ViewProviderTemplateExtension'
     ViewProviderTile = 'TechDrawGui::ViewProviderTile'
     ViewProviderViewClip = 'TechDrawGui::ViewProviderViewClip'
     ViewProviderViewPart = 'TechDrawGui::ViewProviderViewPart'
